bayespy.inference.vmp.nodes.gaussian.GaussianGammaToGaussianWishart.get_moments
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaToGaussianWishart.get_moments